@@ -1,6 +1,6 @@
-#imports essential functions from the unin module.
+#imports essential functions from the vandal package.
 from vandal.misc.global_functions import *
-from vandal import eoq, montecarlo, hub
+from vandal import hub, eoq, montecarlo
 import pandas as pd
 import matplotlib.pyplot as plt
 import random
@@ -20,4 +20,4 @@ def findReplace(directory, find, replace, filePattern):
             with open(filepath, "w") as f:
                 f.write(s)
 
-findReplace(r'unin\unin', 'vandal', 'unin', '*.py')
\ No newline at end of file
+findReplace('vandal', 'vandal', 'unin', '*.py')
\ No newline at end of file
